% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1123.706951117357448 ; 1127.053650927749459 ];

%-- Principal point:
cc = [ 493.560015779452272 ; 492.966503336302310 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.129651858328045 ; 0.181708791768012 ; -0.001244011372941 ; 0.001550525270695 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 3.046360766853609 ; 3.003001789550142 ];

%-- Principal point uncertainty:
cc_error = [ 4.650632542427188 ; 3.548412076299986 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.014905884388938 ; 0.156211789681480 ; 0.000787168264076 ; 0.000977879454261 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 1;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ -2.514398e+00 ; 4.369859e-02 ; -8.040678e-01 ];
Tc_1  = [ -9.223293e+02 ; 8.005973e+02 ; 3.091709e+03 ];
omc_error_1 = [ 3.828768e-03 ; 4.219020e-03 ; 8.665051e-03 ];
Tc_error_1  = [ 5.238329e+00 ; 3.989977e+00 ; 3.771869e+00 ];

